import{select,csv,scaleLinear,max,scalePoint,axisLeft,axisBottom,format} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');


const render = data => {
  
  const xValue = d => d.population;
  const yValue = d => d.country;
  const margin = {top: 20, right: 40, bottom: 20, left: 100};
	const innerWidth = width - margin.left - margin.right;
	const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleLinear()
  	.domain([0, max(data, xValue)])
  	.range([0, innerWidth]);
  
  const yScale = scalePoint()
  	.domain(data.map(yValue))
  	.range([0, innerHeight])
  	.padding(0.5);
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  const xAxis=axisBottom(xScale)
  	.tickFormat(format('.3s'));
  g.append('g')
    .call(axisLeft(yScale))
  	.selectAll('.domain,.tick line')
  		.remove();
  g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  g.selectAll('circle').data(data)
  	.enter().append('circle')
  	.attr('cy', d => yScale(yValue(d)))
  	.attr('cx', d => xScale(xValue(d)))
 		.attr('r', 20);
  g.append('text')
  	.attr('y',-10)
  	.text('Countries');
}; 

csv('data.csv').then(data => {
  data.forEach(d => {
  	d.population = +d.population*1000;
  })
	render(data);
});

